@@ -70,6 +70,18 @@ class TestRequests(unittest.TestCase):
         self.assertEqual(request_id, response.json()['args']['id'])
         self.assertEqual(event['response']['headers'], dict(response.headers))
 
+    def test_post_with_bytes_body(self, start_threads, transport_start_threads, queue):
+        request_id = str(uuid4())
+        url = "https://postman-echo.com/post?id=" + request_id
+        response = requests.post(url, data=b'test')
+        self.assertEqual(response.status_code, 200)
+        queue.assert_called_once_with(EVENT, ANY, False)
+
+        event_type = queue.call_args_list[0][0][0]
+        event = queue.call_args_list[0][0][1]
+        self.assertEqual(event_type, EVENT)
+        self.assertEqual(event['request']['body'].getvalue(), b'test')
+
     def test_chunked(self, start_threads, transport_start_threads, queue):
         url = "https://postman-echo.com/stream/1"
         response = requests.get(url)
@@ -143,3 +155,31 @@ class TestRequests(unittest.TestCase):
         self.assertFalse('response' in event)
         self.assertEqual(event['error']['type'], 'CONNECTION_ERROR')
 
+    def test_connection_error_post(self, start_threads, transport_start_threads, queue):
+        url = "https://fasdftasdfa-echo.com/delay/2"
+        try:
+            response = requests.post(url, data=json.dumps({'key': 'value'}))
+        except ConnectionError as ex:
+            pass
+
+        queue.assert_called_once_with(EVENT, ANY, False)
+        event_type = queue.call_args_list[0][0][0]
+        event = queue.call_args_list[0][0][1]
+        self.assertEqual(event_type, EVENT)
+
+        self.assertFalse('response' in event)
+        self.assertEqual(event['error']['type'], 'CONNECTION_ERROR')
+        self.assertEqual(event['request']['body'].getvalue(), b'{"key": "value"}')
+
+    def test_file(self, start_threads, transport_start_threads, queue):
+        url = "http://httpbin.org/post"
+        with open('tests/instrumentations/test.txt', 'rb') as fp:
+            files = {'upload_file': fp}
+            values = {'DB': 'photcat', 'OUT': 'csv', 'SHORT': 'short'}
+            r = requests.post(url, files=files, data=values)
+        event = queue.call_args_list[0][0][1]
+        self.assertTrue(event['request']['headers']['Content-Type'].startswith('multipart/form-data; boundary='))
+        body = event['request']['body'].getvalue()
+        # content of test.txt
+        self.assertTrue('foobar' in body.decode())
+
